# Test Data

The data in this directory originate from [Red Hat Product Security SBOM examples](https://github.com/RedHatProductSecurity/security-data-guidelines/tree/main/sbom/examples)
and has been modified to match the validation needs. Namely:

- SPDXID can only contain alphanumerics, `-` and `.`
- License List version should be added
- To pass validation, the Creative Commons license had to be changed
  from `CC-BY-4.0` to `CC0-1.0`. Please note I cannot actually grant
  permissions stemming from the `CC0-1.0` as I am not the author of this data.
